# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainWindowUi.ui'
#
# Created by: PyQt5 UI code generator 5.12.3
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1136, 734)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName("gridLayout")
        self.splitterTopBottom = QtWidgets.QSplitter(self.centralwidget)
        self.splitterTopBottom.setOrientation(QtCore.Qt.Vertical)
        self.splitterTopBottom.setObjectName("splitterTopBottom")
        self.gridLayoutWidget = QtWidgets.QWidget(self.splitterTopBottom)
        self.gridLayoutWidget.setObjectName("gridLayoutWidget")
        self.gridLayoutTop = QtWidgets.QGridLayout(self.gridLayoutWidget)
        self.gridLayoutTop.setContentsMargins(0, 0, 0, 0)
        self.gridLayoutTop.setObjectName("gridLayoutTop")
        self.scrollAreaLeft = QtWidgets.QScrollArea(self.gridLayoutWidget)
        self.scrollAreaLeft.setMinimumSize(QtCore.QSize(300, 0))
        self.scrollAreaLeft.setMaximumSize(QtCore.QSize(300, 16777215))
        self.scrollAreaLeft.setFocusPolicy(QtCore.Qt.NoFocus)
        self.scrollAreaLeft.setWidgetResizable(True)
        self.scrollAreaLeft.setObjectName("scrollAreaLeft")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 284, 550))
        self.scrollAreaWidgetContents.setMinimumSize(QtCore.QSize(250, 550))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.scrollAreaWidgetContents)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.groupBoxSubjects = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.groupBoxSubjects.setObjectName("groupBoxSubjects")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.groupBoxSubjects)
        self.gridLayout_12.setContentsMargins(9, 9, 9, 9)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.pushButtonAddSubjects = QtWidgets.QPushButton(self.groupBoxSubjects)
        self.pushButtonAddSubjects.setObjectName("pushButtonAddSubjects")
        self.gridLayout_12.addWidget(self.pushButtonAddSubjects, 4, 0, 1, 1)
        self.listWidgetSubjects = QtWidgets.QListWidget(self.groupBoxSubjects)
        self.listWidgetSubjects.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.listWidgetSubjects.setObjectName("listWidgetSubjects")
        self.gridLayout_12.addWidget(self.listWidgetSubjects, 1, 0, 1, 1)
        self.pushButtonRemoveSubject = QtWidgets.QPushButton(self.groupBoxSubjects)
        self.pushButtonRemoveSubject.setObjectName("pushButtonRemoveSubject")
        self.gridLayout_12.addWidget(self.pushButtonRemoveSubject, 3, 0, 1, 1)
        self.pushButtonActivateSubject = QtWidgets.QPushButton(self.groupBoxSubjects)
        self.pushButtonActivateSubject.setObjectName("pushButtonActivateSubject")
        self.gridLayout_12.addWidget(self.pushButtonActivateSubject, 2, 0, 1, 1)
        self.gridLayout_2.addWidget(self.groupBoxSubjects, 2, 0, 1, 1)
        self.groupBoxExperiment = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.groupBoxExperiment.setObjectName("groupBoxExperiment")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupBoxExperiment)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.labelExperimentAuthorValue = QtWidgets.QLabel(self.groupBoxExperiment)
        self.labelExperimentAuthorValue.setText("")
        self.labelExperimentAuthorValue.setObjectName("labelExperimentAuthorValue")
        self.gridLayout_4.addWidget(self.labelExperimentAuthorValue, 1, 1, 1, 2)
        self.labelExperimentAuthor = QtWidgets.QLabel(self.groupBoxExperiment)
        self.labelExperimentAuthor.setObjectName("labelExperimentAuthor")
        self.gridLayout_4.addWidget(self.labelExperimentAuthor, 1, 0, 1, 1)
        self.labelExperimentNameValue = QtWidgets.QLabel(self.groupBoxExperiment)
        self.labelExperimentNameValue.setText("")
        self.labelExperimentNameValue.setObjectName("labelExperimentNameValue")
        self.gridLayout_4.addWidget(self.labelExperimentNameValue, 0, 1, 1, 2)
        self.labelExperimentName = QtWidgets.QLabel(self.groupBoxExperiment)
        self.labelExperimentName.setObjectName("labelExperimentName")
        self.gridLayout_4.addWidget(self.labelExperimentName, 0, 0, 1, 1)
        self.pushButtonChannelGroups = QtWidgets.QPushButton(self.groupBoxExperiment)
        self.pushButtonChannelGroups.setObjectName("pushButtonChannelGroups")
        self.gridLayout_4.addWidget(self.pushButtonChannelGroups, 2, 0, 1, 3)
        self.pushButtonPipelines = QtWidgets.QPushButton(self.groupBoxExperiment)
        self.pushButtonPipelines.setObjectName("pushButtonPipelines")
        self.gridLayout_4.addWidget(self.pushButtonPipelines, 3, 0, 1, 3)
        self.gridLayout_2.addWidget(self.groupBoxExperiment, 0, 0, 1, 1)
        self.scrollAreaLeft.setWidget(self.scrollAreaWidgetContents)
        self.gridLayoutTop.addWidget(self.scrollAreaLeft, 0, 0, 1, 1)
        self.scrollAreaRight = QtWidgets.QScrollArea(self.gridLayoutWidget)
        self.scrollAreaRight.setFocusPolicy(QtCore.Qt.NoFocus)
        self.scrollAreaRight.setWidgetResizable(True)
        self.scrollAreaRight.setObjectName("scrollAreaRight")
        self.scrollAreaWidgetContents_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 800, 700))
        self.scrollAreaWidgetContents_2.setMinimumSize(QtCore.QSize(800, 700))
        self.scrollAreaWidgetContents_2.setObjectName("scrollAreaWidgetContents_2")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.scrollAreaWidgetContents_2)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.tabWidget = QtWidgets.QTabWidget(self.scrollAreaWidgetContents_2)
        self.tabWidget.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setMinimumSize(QtCore.QSize(200, 400))
        self.tabWidget.setMaximumSize(QtCore.QSize(20000, 16777215))
        self.tabWidget.setObjectName("tabWidget")
        self.gridLayout_3.addWidget(self.tabWidget, 0, 0, 1, 1)
        self.scrollAreaRight.setWidget(self.scrollAreaWidgetContents_2)
        self.gridLayoutTop.addWidget(self.scrollAreaRight, 0, 1, 1, 1)
        self.textEditConsole = QtWidgets.QTextEdit(self.splitterTopBottom)
        self.textEditConsole.setMinimumSize(QtCore.QSize(0, 0))
        self.textEditConsole.setFocusPolicy(QtCore.Qt.NoFocus)
        self.textEditConsole.setObjectName("textEditConsole")
        self.gridLayout.addWidget(self.splitterTopBottom, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1136, 20))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuTools = QtWidgets.QMenu(self.menubar)
        self.menuTools.setObjectName("menuTools")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionCreateExperiment = QtWidgets.QAction(MainWindow)
        self.actionCreateExperiment.setObjectName("actionCreateExperiment")
        self.actionOpenExperiment = QtWidgets.QAction(MainWindow)
        self.actionOpenExperiment.setObjectName("actionOpenExperiment")
        self.actionShowExperimentInfo = QtWidgets.QAction(MainWindow)
        self.actionShowExperimentInfo.setObjectName("actionShowExperimentInfo")
        self.actionQuit = QtWidgets.QAction(MainWindow)
        self.actionQuit.setObjectName("actionQuit")
        self.actionShowLog = QtWidgets.QAction(MainWindow)
        self.actionShowLog.setObjectName("actionShowLog")
        self.actionPreferences = QtWidgets.QAction(MainWindow)
        self.actionPreferences.setObjectName("actionPreferences")
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionActions = QtWidgets.QAction(MainWindow)
        self.actionActions.setObjectName("actionActions")
        self.menuFile.addAction(self.actionCreateExperiment)
        self.menuFile.addAction(self.actionOpenExperiment)
        self.menuFile.addAction(self.actionQuit)
        self.menuTools.addAction(self.actionActions)
        self.menuTools.addAction(self.actionPreferences)
        self.menuHelp.addAction(self.actionAbout)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(-1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.scrollAreaLeft, self.pushButtonChannelGroups)
        MainWindow.setTabOrder(self.pushButtonChannelGroups, self.listWidgetSubjects)
        MainWindow.setTabOrder(self.listWidgetSubjects, self.pushButtonActivateSubject)
        MainWindow.setTabOrder(self.pushButtonActivateSubject, self.pushButtonRemoveSubject)
        MainWindow.setTabOrder(self.pushButtonRemoveSubject, self.pushButtonAddSubjects)
        MainWindow.setTabOrder(self.pushButtonAddSubjects, self.scrollAreaRight)
        MainWindow.setTabOrder(self.scrollAreaRight, self.tabWidget)
        MainWindow.setTabOrder(self.tabWidget, self.textEditConsole)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Meggie"))
        self.groupBoxSubjects.setTitle(_translate("MainWindow", "Subjects"))
        self.pushButtonAddSubjects.setText(_translate("MainWindow", "Add new..."))
        self.pushButtonRemoveSubject.setText(_translate("MainWindow", "Remove selected"))
        self.pushButtonActivateSubject.setText(_translate("MainWindow", "Activate selected"))
        self.groupBoxExperiment.setTitle(_translate("MainWindow", "Experiment"))
        self.labelExperimentAuthor.setText(_translate("MainWindow", "Author:"))
        self.labelExperimentName.setText(_translate("MainWindow", "Name:"))
        self.pushButtonChannelGroups.setText(_translate("MainWindow", "Channel groups..."))
        self.pushButtonPipelines.setText(_translate("MainWindow", "Change pipeline..."))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuTools.setTitle(_translate("MainWindow", "Tools"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.actionCreateExperiment.setText(_translate("MainWindow", "Create new experiment..."))
        self.actionOpenExperiment.setText(_translate("MainWindow", "Open experiment..."))
        self.actionShowExperimentInfo.setText(_translate("MainWindow", "Show experiment info..."))
        self.actionQuit.setText(_translate("MainWindow", "Quit"))
        self.actionShowLog.setText(_translate("MainWindow", "Show mne log..."))
        self.actionPreferences.setText(_translate("MainWindow", "Preferences..."))
        self.actionAbout.setText(_translate("MainWindow", "About..."))
        self.actionActions.setText(_translate("MainWindow", "Show past actions..."))
