# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'bitSelectionDialogUi.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(919, 175)
        self.gridLayout = QtWidgets.QGridLayout(Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.label = QtWidgets.QLabel(Dialog)
        self.label.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label.setObjectName("label")
        self.horizontalLayout_3.addWidget(self.label)
        self.labelID = QtWidgets.QLabel(Dialog)
        self.labelID.setText("")
        self.labelID.setObjectName("labelID")
        self.horizontalLayout_3.addWidget(self.labelID)
        self.label_3 = QtWidgets.QLabel(Dialog)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_3.addWidget(self.label_3)
        self.labelMask = QtWidgets.QLabel(Dialog)
        self.labelMask.setText("")
        self.labelMask.setObjectName("labelMask")
        self.horizontalLayout_3.addWidget(self.labelMask)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout16 = QtWidgets.QVBoxLayout()
        self.verticalLayout16.setObjectName("verticalLayout16")
        self.pushButton16 = QtWidgets.QPushButton(Dialog)
        self.pushButton16.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton16.setText("")
        self.pushButton16.setObjectName("pushButton16")
        self.verticalLayout16.addWidget(self.pushButton16)
        self.bitLabel16 = QtWidgets.QLabel(Dialog)
        self.bitLabel16.setMaximumSize(QtCore.QSize(40, 16777215))
        self.bitLabel16.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel16.setObjectName("bitLabel16")
        self.verticalLayout16.addWidget(self.bitLabel16)
        self.horizontalLayout.addLayout(self.verticalLayout16)
        self.line16 = QtWidgets.QFrame(Dialog)
        self.line16.setFrameShape(QtWidgets.QFrame.VLine)
        self.line16.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line16.setObjectName("line16")
        self.horizontalLayout.addWidget(self.line16)
        self.verticalLayout15 = QtWidgets.QVBoxLayout()
        self.verticalLayout15.setObjectName("verticalLayout15")
        self.pushButton15 = QtWidgets.QPushButton(Dialog)
        self.pushButton15.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButton15.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton15.setText("")
        self.pushButton15.setObjectName("pushButton15")
        self.verticalLayout15.addWidget(self.pushButton15)
        self.bitLabel15 = QtWidgets.QLabel(Dialog)
        self.bitLabel15.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel15.setObjectName("bitLabel15")
        self.verticalLayout15.addWidget(self.bitLabel15)
        self.horizontalLayout.addLayout(self.verticalLayout15)
        self.line15 = QtWidgets.QFrame(Dialog)
        self.line15.setFrameShape(QtWidgets.QFrame.VLine)
        self.line15.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line15.setObjectName("line15")
        self.horizontalLayout.addWidget(self.line15)
        self.verticalLayout14 = QtWidgets.QVBoxLayout()
        self.verticalLayout14.setObjectName("verticalLayout14")
        self.pushButton14 = QtWidgets.QPushButton(Dialog)
        self.pushButton14.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton14.setText("")
        self.pushButton14.setObjectName("pushButton14")
        self.verticalLayout14.addWidget(self.pushButton14)
        self.bitLabel14 = QtWidgets.QLabel(Dialog)
        self.bitLabel14.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel14.setObjectName("bitLabel14")
        self.verticalLayout14.addWidget(self.bitLabel14)
        self.horizontalLayout.addLayout(self.verticalLayout14)
        self.line14 = QtWidgets.QFrame(Dialog)
        self.line14.setFrameShape(QtWidgets.QFrame.VLine)
        self.line14.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line14.setObjectName("line14")
        self.horizontalLayout.addWidget(self.line14)
        self.verticalLayout13 = QtWidgets.QVBoxLayout()
        self.verticalLayout13.setObjectName("verticalLayout13")
        self.pushButton13 = QtWidgets.QPushButton(Dialog)
        self.pushButton13.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton13.setText("")
        self.pushButton13.setObjectName("pushButton13")
        self.verticalLayout13.addWidget(self.pushButton13)
        self.bitLabel13 = QtWidgets.QLabel(Dialog)
        self.bitLabel13.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel13.setObjectName("bitLabel13")
        self.verticalLayout13.addWidget(self.bitLabel13)
        self.horizontalLayout.addLayout(self.verticalLayout13)
        self.line13 = QtWidgets.QFrame(Dialog)
        self.line13.setFrameShape(QtWidgets.QFrame.VLine)
        self.line13.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line13.setObjectName("line13")
        self.horizontalLayout.addWidget(self.line13)
        self.verticalLayout12 = QtWidgets.QVBoxLayout()
        self.verticalLayout12.setObjectName("verticalLayout12")
        self.pushButton12 = QtWidgets.QPushButton(Dialog)
        self.pushButton12.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton12.setText("")
        self.pushButton12.setObjectName("pushButton12")
        self.verticalLayout12.addWidget(self.pushButton12)
        self.bitLabel12 = QtWidgets.QLabel(Dialog)
        self.bitLabel12.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel12.setObjectName("bitLabel12")
        self.verticalLayout12.addWidget(self.bitLabel12)
        self.horizontalLayout.addLayout(self.verticalLayout12)
        self.line12 = QtWidgets.QFrame(Dialog)
        self.line12.setFrameShape(QtWidgets.QFrame.VLine)
        self.line12.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line12.setObjectName("line12")
        self.horizontalLayout.addWidget(self.line12)
        self.verticalLayout11 = QtWidgets.QVBoxLayout()
        self.verticalLayout11.setObjectName("verticalLayout11")
        self.pushButton11 = QtWidgets.QPushButton(Dialog)
        self.pushButton11.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton11.setText("")
        self.pushButton11.setObjectName("pushButton11")
        self.verticalLayout11.addWidget(self.pushButton11)
        self.bitLabel11 = QtWidgets.QLabel(Dialog)
        self.bitLabel11.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel11.setObjectName("bitLabel11")
        self.verticalLayout11.addWidget(self.bitLabel11)
        self.horizontalLayout.addLayout(self.verticalLayout11)
        self.line11 = QtWidgets.QFrame(Dialog)
        self.line11.setFrameShape(QtWidgets.QFrame.VLine)
        self.line11.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line11.setObjectName("line11")
        self.horizontalLayout.addWidget(self.line11)
        self.verticalLayout10 = QtWidgets.QVBoxLayout()
        self.verticalLayout10.setObjectName("verticalLayout10")
        self.pushButton10 = QtWidgets.QPushButton(Dialog)
        self.pushButton10.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton10.setText("")
        self.pushButton10.setObjectName("pushButton10")
        self.verticalLayout10.addWidget(self.pushButton10)
        self.bitLabel10 = QtWidgets.QLabel(Dialog)
        self.bitLabel10.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel10.setObjectName("bitLabel10")
        self.verticalLayout10.addWidget(self.bitLabel10)
        self.horizontalLayout.addLayout(self.verticalLayout10)
        self.line10 = QtWidgets.QFrame(Dialog)
        self.line10.setFrameShape(QtWidgets.QFrame.VLine)
        self.line10.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line10.setObjectName("line10")
        self.horizontalLayout.addWidget(self.line10)
        self.verticalLayout9 = QtWidgets.QVBoxLayout()
        self.verticalLayout9.setObjectName("verticalLayout9")
        self.pushButton9 = QtWidgets.QPushButton(Dialog)
        self.pushButton9.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton9.setText("")
        self.pushButton9.setObjectName("pushButton9")
        self.verticalLayout9.addWidget(self.pushButton9)
        self.bitLabel9 = QtWidgets.QLabel(Dialog)
        self.bitLabel9.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel9.setObjectName("bitLabel9")
        self.verticalLayout9.addWidget(self.bitLabel9)
        self.horizontalLayout.addLayout(self.verticalLayout9)
        self.line9 = QtWidgets.QFrame(Dialog)
        self.line9.setFrameShape(QtWidgets.QFrame.VLine)
        self.line9.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line9.setObjectName("line9")
        self.horizontalLayout.addWidget(self.line9)
        self.verticalLayout8 = QtWidgets.QVBoxLayout()
        self.verticalLayout8.setObjectName("verticalLayout8")
        self.pushButton8 = QtWidgets.QPushButton(Dialog)
        self.pushButton8.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton8.setText("")
        self.pushButton8.setObjectName("pushButton8")
        self.verticalLayout8.addWidget(self.pushButton8)
        self.bitLabel8 = QtWidgets.QLabel(Dialog)
        self.bitLabel8.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel8.setObjectName("bitLabel8")
        self.verticalLayout8.addWidget(self.bitLabel8)
        self.horizontalLayout.addLayout(self.verticalLayout8)
        self.line8 = QtWidgets.QFrame(Dialog)
        self.line8.setFrameShape(QtWidgets.QFrame.VLine)
        self.line8.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line8.setObjectName("line8")
        self.horizontalLayout.addWidget(self.line8)
        self.verticalLayout7 = QtWidgets.QVBoxLayout()
        self.verticalLayout7.setObjectName("verticalLayout7")
        self.pushButton7 = QtWidgets.QPushButton(Dialog)
        self.pushButton7.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton7.setText("")
        self.pushButton7.setObjectName("pushButton7")
        self.verticalLayout7.addWidget(self.pushButton7)
        self.bitLabel7 = QtWidgets.QLabel(Dialog)
        self.bitLabel7.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel7.setObjectName("bitLabel7")
        self.verticalLayout7.addWidget(self.bitLabel7)
        self.horizontalLayout.addLayout(self.verticalLayout7)
        self.line7 = QtWidgets.QFrame(Dialog)
        self.line7.setFrameShape(QtWidgets.QFrame.VLine)
        self.line7.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line7.setObjectName("line7")
        self.horizontalLayout.addWidget(self.line7)
        self.verticalLayout6 = QtWidgets.QVBoxLayout()
        self.verticalLayout6.setObjectName("verticalLayout6")
        self.pushButton6 = QtWidgets.QPushButton(Dialog)
        self.pushButton6.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton6.setText("")
        self.pushButton6.setObjectName("pushButton6")
        self.verticalLayout6.addWidget(self.pushButton6)
        self.bitLabel6 = QtWidgets.QLabel(Dialog)
        self.bitLabel6.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel6.setObjectName("bitLabel6")
        self.verticalLayout6.addWidget(self.bitLabel6)
        self.horizontalLayout.addLayout(self.verticalLayout6)
        self.line6 = QtWidgets.QFrame(Dialog)
        self.line6.setFrameShape(QtWidgets.QFrame.VLine)
        self.line6.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line6.setObjectName("line6")
        self.horizontalLayout.addWidget(self.line6)
        self.verticalLayout5 = QtWidgets.QVBoxLayout()
        self.verticalLayout5.setObjectName("verticalLayout5")
        self.pushButton5 = QtWidgets.QPushButton(Dialog)
        self.pushButton5.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton5.setText("")
        self.pushButton5.setObjectName("pushButton5")
        self.verticalLayout5.addWidget(self.pushButton5)
        self.bitLabel5 = QtWidgets.QLabel(Dialog)
        self.bitLabel5.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel5.setObjectName("bitLabel5")
        self.verticalLayout5.addWidget(self.bitLabel5)
        self.horizontalLayout.addLayout(self.verticalLayout5)
        self.line5 = QtWidgets.QFrame(Dialog)
        self.line5.setFrameShape(QtWidgets.QFrame.VLine)
        self.line5.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line5.setObjectName("line5")
        self.horizontalLayout.addWidget(self.line5)
        self.verticalLayout4 = QtWidgets.QVBoxLayout()
        self.verticalLayout4.setObjectName("verticalLayout4")
        self.pushButton4 = QtWidgets.QPushButton(Dialog)
        self.pushButton4.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton4.setText("")
        self.pushButton4.setObjectName("pushButton4")
        self.verticalLayout4.addWidget(self.pushButton4)
        self.bitLabel4 = QtWidgets.QLabel(Dialog)
        self.bitLabel4.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel4.setObjectName("bitLabel4")
        self.verticalLayout4.addWidget(self.bitLabel4)
        self.horizontalLayout.addLayout(self.verticalLayout4)
        self.line4 = QtWidgets.QFrame(Dialog)
        self.line4.setFrameShape(QtWidgets.QFrame.VLine)
        self.line4.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line4.setObjectName("line4")
        self.horizontalLayout.addWidget(self.line4)
        self.verticalLayout3 = QtWidgets.QVBoxLayout()
        self.verticalLayout3.setObjectName("verticalLayout3")
        self.pushButton3 = QtWidgets.QPushButton(Dialog)
        self.pushButton3.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton3.setText("")
        self.pushButton3.setObjectName("pushButton3")
        self.verticalLayout3.addWidget(self.pushButton3)
        self.bitLabel3 = QtWidgets.QLabel(Dialog)
        self.bitLabel3.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel3.setObjectName("bitLabel3")
        self.verticalLayout3.addWidget(self.bitLabel3)
        self.horizontalLayout.addLayout(self.verticalLayout3)
        self.line3 = QtWidgets.QFrame(Dialog)
        self.line3.setFrameShape(QtWidgets.QFrame.VLine)
        self.line3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line3.setObjectName("line3")
        self.horizontalLayout.addWidget(self.line3)
        self.verticalLayout2 = QtWidgets.QVBoxLayout()
        self.verticalLayout2.setObjectName("verticalLayout2")
        self.pushButton2 = QtWidgets.QPushButton(Dialog)
        self.pushButton2.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton2.setText("")
        self.pushButton2.setObjectName("pushButton2")
        self.verticalLayout2.addWidget(self.pushButton2)
        self.bitLabel2 = QtWidgets.QLabel(Dialog)
        self.bitLabel2.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel2.setObjectName("bitLabel2")
        self.verticalLayout2.addWidget(self.bitLabel2)
        self.horizontalLayout.addLayout(self.verticalLayout2)
        self.line2 = QtWidgets.QFrame(Dialog)
        self.line2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line2.setObjectName("line2")
        self.horizontalLayout.addWidget(self.line2)
        self.verticalLayout1 = QtWidgets.QVBoxLayout()
        self.verticalLayout1.setObjectName("verticalLayout1")
        self.pushButton1 = QtWidgets.QPushButton(Dialog)
        self.pushButton1.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton1.setText("")
        self.pushButton1.setObjectName("pushButton1")
        self.verticalLayout1.addWidget(self.pushButton1)
        self.bitLabel1 = QtWidgets.QLabel(Dialog)
        self.bitLabel1.setAlignment(QtCore.Qt.AlignCenter)
        self.bitLabel1.setObjectName("bitLabel1")
        self.verticalLayout1.addWidget(self.bitLabel1)
        self.horizontalLayout.addLayout(self.verticalLayout1)
        self.verticalLayout.addLayout(self.horizontalLayout)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem2)
        self.gridLayout.addLayout(self.verticalLayout, 0, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem3)
        self.pushButtonReject = QtWidgets.QPushButton(Dialog)
        self.pushButtonReject.setObjectName("pushButtonReject")
        self.horizontalLayout_2.addWidget(self.pushButtonReject)
        self.pushButtonAccept = QtWidgets.QPushButton(Dialog)
        self.pushButtonAccept.setObjectName("pushButtonAccept")
        self.horizontalLayout_2.addWidget(self.pushButtonAccept)
        self.gridLayout.addLayout(self.horizontalLayout_2, 1, 0, 1, 1)

        self.retranslateUi(Dialog)
        self.pushButtonReject.clicked.connect(Dialog.reject)
        self.pushButtonAccept.clicked.connect(Dialog.accept)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Meggie - Edit"))
        self.label.setText(_translate("Dialog", "ID:"))
        self.label_3.setText(_translate("Dialog", "Mask:"))
        self.bitLabel16.setText(_translate("Dialog", "16"))
        self.bitLabel15.setText(_translate("Dialog", "15"))
        self.bitLabel14.setText(_translate("Dialog", "14"))
        self.bitLabel13.setText(_translate("Dialog", "13"))
        self.bitLabel12.setText(_translate("Dialog", "12"))
        self.bitLabel11.setText(_translate("Dialog", "11"))
        self.bitLabel10.setText(_translate("Dialog", "10"))
        self.bitLabel9.setText(_translate("Dialog", "9"))
        self.bitLabel8.setText(_translate("Dialog", "8"))
        self.bitLabel7.setText(_translate("Dialog", "7"))
        self.bitLabel6.setText(_translate("Dialog", "6"))
        self.bitLabel5.setText(_translate("Dialog", "5"))
        self.bitLabel4.setText(_translate("Dialog", "4"))
        self.bitLabel3.setText(_translate("Dialog", "3"))
        self.bitLabel2.setText(_translate("Dialog", "2"))
        self.bitLabel1.setText(_translate("Dialog", "1"))
        self.pushButtonReject.setText(_translate("Dialog", "Cancel"))
        self.pushButtonAccept.setText(_translate("Dialog", "Ok"))

